***
<H1 align="center">Semantyk</H1>
<p align="center">
  <i>– Ideas Wonder –</i><br><br>
  <img src="https://raw.githubusercontent.com/semantyk/Semantyk/master/docs/Semantyk.png" alt="Semantyk" width="250"/><br><br>
  <b>Author: Daniel Bakas Amuchástegui</b><br>
  August 31, 2017<br>
  <i>Copyright © 2020 Semantyk. All rights reserved.</i>
</p>

***
[![Build Status](https://travis-ci.org/RDFLib/rdflib.png?branch=master)](https://travis-ci.org/semantyk/Semantyk)
[![GitHub stars](https://raster.shields.io/github/stars/semantyk/Semantyk.png)](https://github.com/semantyk/Semantyk/stargazers)
[![PyPI](https://img.shields.io/pypi/v/semantyk.svg)](https://pypi.python.org/pypi/semantyk)
[![PyPI](https://img.shields.io/pypi/pyversions/semantyk.svg)](https://pypi.python.org/pypi/semantyk)